@@ -48,18 +48,14 @@ required_params = ['EndpointMap', 'ServiceNetMap', 'DefaultPasswords',
 # so they need to be listed twice.  Once the deprecated version can be removed
 # the duplicate entries can be as well.
 envs_containing_endpoint_map = ['no-tls-endpoints-public-ip.yaml',
-                                'tls-endpoints-public-dns.yaml',
-                                'tls-endpoints-public-ip.yaml',
-                                'tls-everywhere-endpoints-dns.yaml',
-                                'no-tls-endpoints-public-ip.yaml',
                                 'tls-endpoints-public-dns.yaml',
                                 'tls-endpoints-public-ip.yaml',
                                 'tls-everywhere-endpoints-dns.yaml']
 ENDPOINT_MAP_FILE = 'endpoint_map.yaml'
-OPTIONAL_SECTIONS = ['workflow_tasks', 'cellv2_discovery']
+OPTIONAL_SECTIONS = ['cellv2_discovery']
 REQUIRED_DOCKER_SECTIONS = ['service_name', 'docker_config', 'puppet_config',
                             'config_settings']
-OPTIONAL_DOCKER_SECTIONS = ['docker_puppet_tasks', 'upgrade_tasks',
+OPTIONAL_DOCKER_SECTIONS = ['container_puppet_tasks', 'upgrade_tasks',
                             'deploy_steps_tasks',
                             'pre_upgrade_rolling_tasks',
                             'fast_forward_upgrade_tasks',
@@ -69,7 +65,7 @@ OPTIONAL_DOCKER_SECTIONS = ['docker_puppet_tasks', 'upgrade_tasks',
                             'host_prep_tasks', 'metadata_settings',
                             'kolla_config', 'global_config_settings',
                             'external_deploy_tasks', 'external_post_deploy_tasks',
-                            'docker_config_scripts', 'step_config',
+                            'container_config_scripts', 'step_config',
                             'monitoring_subscription',
                             'external_update_tasks', 'external_upgrade_tasks']
 # ansible tasks cannot be an empty dict or ansible is unhappy
@@ -228,27 +224,25 @@ PREFERRED_CAMEL_CASE = {
 # If a filename is not found in the overrides then the top level directory is
 # used to determine which validation method to use.
 VALIDATE_PUPPET_OVERRIDE = {
+  # deployment/rabbitmq/rabbitmq-messaging*.yaml provide oslo_messaging services
+  './deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml': False,
+  './deployment/rabbitmq/rabbitmq-messaging-notify-container-puppet.yaml': False,
+  './deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml': False,
   # docker/services/messaging/*.yaml provide oslo_messaging services
-  './docker/services/messaging/notify-rabbitmq-shared.yaml': False,
-  './docker/services/messaging/notify-rabbitmq.yaml': False,
-  './docker/services/messaging/rpc-rabbitmq.yaml': False,
-  './docker/services/messaging/rpc-qdrouterd.yaml': False,
+  './deployment/messaging/rpc-qdrouterd-container-puppet.yaml': False,
   # docker/services/pacemaker/*-rabbitmq.yaml provide oslo_messaging services
-  './docker/services/pacemaker/notify-rabbitmq.yaml': False,
-  './docker/services/pacemaker/rpc-rabbitmq.yaml': False,
+  './deployment/rabbitmq/rabbitmq-messaging-notify-pacemaker-puppet.yaml': False,
+  './deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml': False,
   # qdr aliases rabbitmq service to provide alternative messaging backend
   './puppet/services/qdr.yaml': False,
   # puppet/services/messaging/*.yaml provide oslo_messaging services
-  './puppet/services/messaging/notify-rabbitmq-shared.yaml': False,
-  './puppet/services/messaging/notify-rabbitmq.yaml': False,
-  './puppet/services/messaging/rpc-rabbitmq.yaml': False,
   './puppet/services/messaging/rpc-qdrouterd.yaml': False,
 
 }
 VALIDATE_DOCKER_OVERRIDE = {
-  # docker/services/messaging/notify-rabbitmq-shared.yaml does not
+  # deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml does not
   # deploy container
-  './docker/services/messaging/notify-rabbitmq-shared.yaml': False,
+  './deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml': False,
 }
 DEPLOYMENT_RESOURCE_TYPES = [
     'OS::Heat::SoftwareDeploymentGroup',
@@ -264,9 +258,8 @@ CONFIG_RESOURCE_TYPES = [
     'OS::Heat::StructuredConfig'
 ]
 
-VALID_ANSIBLE_UPGRADE_TAGS = [ 'common', 'validation', 'pre-upgrade' ]
 WORKFLOW_TASKS_EXCLUSIONS = [
-    './docker/services/octavia/octavia-deployment-config.yaml',
+    './deployment/octavia/octavia-deployment-config.yaml',
     './docker/services/ceph-ansible/ceph-external.yaml',
     './docker/services/ceph-ansible/ceph-osd.yaml',
     './docker/services/ceph-ansible/ceph-rbdmirror.yaml',
@@ -703,12 +696,6 @@ def validate_docker_service(filename, tpl):
                 print('ERROR: fast_forward_post_upgrade_tasks validation failed')
                 return 1
 
-        if 'workflow_tasks' in role_data and \
-                filename not in WORKFLOW_TASKS_EXCLUSIONS:
-            print('ERROR: workflow_tasks are no longer supported '
-                  'with config-download in %s.' % filename)
-            return 1
-
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -904,6 +891,13 @@ def validate_service_hiera_interpol(f, tpl):
             # Omit if external deploy tasks in the path
             if 'external_deploy_tasks' in path:
                 continue
+            # Omit apache remoteip proxy_ips
+            if 'apache::mod::remoteip::proxy_ips' in path:
+                continue
+            # Omit Designate rndc_allowed_addressses
+            if ('tripleo::profile::base::designate::rndc_allowed_addresses' in
+                    path):
+                continue
 
             # Omit if not a part of {get_param: [ServiceNetMap ...
             if not enter_lists and path[-1] != 'get_param':
@@ -916,7 +910,7 @@ def validate_service_hiera_interpol(f, tpl):
             # name. The only exception is allow anything under
             # str_replace['params'] ('str_replace;params' in the str notation).
             # We need to escape because of '$' char may be in templated params.
-            query = re.compile(r'\\;str\\_replace\\;params\\;\S*?net',
+            query = re.compile(r'\\;str(\\)?_replace\\;params\\;\S*?net',
                                re.IGNORECASE)
             if not query.search(re.escape(path_str)):
                 # Keep parsing, if foo_vip_network, or anything
@@ -1118,8 +1112,9 @@ def validate(filename, param_map):
         # NOTE(mandre): Same goes for the openshift network data where it
         # contains only a subset of the overcloud networks.
         if (filename.startswith('./network_data_') and
-                not (filename.endswith('routed.yaml') or
-                     filename.endswith('openshift.yaml'))):
+                not filename.endswith(('routed.yaml',
+                                       'openshift.yaml',
+                                       'undercloud.yaml'))):
             result = validate_network_data_file(filename)
             retval |= result
         else:
@@ -1144,7 +1139,10 @@ def validate(filename, param_map):
             str_p = '\'%s\'' % p
             in_resources = str_p in str(tpl.get('resources', {}))
             in_outputs = str_p in str(tpl.get('outputs', {}))
-            if not in_resources and not in_outputs and args.quiet < 2:
+            in_conditions = str_p in str(tpl.get('conditions', {}))
+            in_parameter_groups = str_p in str(tpl.get('parameter_groups', {}))
+            if (not in_resources and not in_outputs and not in_conditions
+                and not in_parameter_groups and args.quiet < 2):
                 print('Warning: parameter %s in template %s '
                       'appears to be unused' % (p, filename))
 
@@ -1185,21 +1183,15 @@ def validate_upgrade_tasks(upgrade_tasks):
 
     for task in upgrade_tasks:
         task_name = task.get("name", "")
-        if task.get("tags"):
-            if (task["tags"] not in VALID_ANSIBLE_UPGRADE_TAGS):
-                print('ERROR: Task (%s) includes unexpected \'tags: (%s)\' ' % (task_name, task["tags"]))
-                return 1
+        whenline = task.get("when", "")
+        if (type(whenline) == list):
+            if any('step|int ' in condition for condition in whenline) and ('step|int == ' not in whenline[0]):
+                    print('ERROR: \'step|int ==\' condition should be evaluated first in when conditions for task (%s)'  % (task))
+                    return 1
         else:
-
-            whenline = task.get("when", "")
-            if (type(whenline) == list):
-                if any('step|int ' in condition for condition in whenline) and ('step|int == ' not in whenline[0]):
-                        print('ERROR: \'step|int ==\' condition should be evaluated first in when conditions for task (%s)'  % (task))
-                        return 1
-            else:
-                if (' and ' in whenline) and (' or ' not in whenline) \
-                        and args.quiet < 2:
-                    print("Warning: Consider specifying \'and\' conditions as a list to improve readability in task: \"%s\"" %  (task_name))
+            if (' and ' in whenline) and (' or ' not in whenline) \
+                    and args.quiet < 2:
+                print("Warning: Consider specifying \'and\' conditions as a list to improve readability in task: \"%s\"" %  (task_name))
     return 0
 
 def validate_network_data_file(data_file_path):
